"{ Package: 'stx:goodies/xtreams/transforms/tests' }"

"{ NameSpace: Xtreams }"

TestCase subclass:#InterpretingStreamTest
	instanceVariableNames:'stream'
	classVariableNames:''
	poolDictionaries:''
	category:'Xtreams-Transforms-Tests'
!


!InterpretingStreamTest methodsFor:'tests'!

testDouble
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #double.
	interpreting put: (SmallInteger minVal - 1.5).
	interpreting put: (SmallInteger maxVal + 1.5).
	interpreting := stream contents reading interpreting: #double.
	self assert: interpreting get = (SmallInteger minVal - 1.5).
	self assert: interpreting get = (SmallInteger maxVal + 1.5)
!

testFloat
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #float.
	-50.0 to: 50.0 by: 0.5 do: [:each | interpreting put: each].
	self assert: (stream contents reading interpreting: #float) rest = (-50 to: 50 by: 0.5) asArray
!

testSignedChar
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #signedChar.
	-120 to: 120 do: [:each | interpreting put: each].
	interpreting := stream contents reading interpreting: #signedChar.
	self assert: interpreting rest = (-120 to: 120) asArray
!

testSignedLong
	| interpreting negative positive |
	stream := ByteArray new writing.
	negative := -268435456. "SmallInteger minVal // 2 in 32-bits"
	positive :=  268435455. "SmallInteger maxVal // 2 in 32-bits"
	interpreting := stream interpreting: #signedLong.
	interpreting put: negative.
	interpreting put: positive.
	interpreting := stream contents reading interpreting: #signedLong.
	self assert: interpreting get = negative.
	self assert: interpreting get = positive
!

testSignedLonglong
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #signedLonglong.
	interpreting put: (SmallInteger minVal // 2) - 1.
	interpreting put: (SmallInteger maxVal // 2) + 1.
	interpreting := stream contents reading interpreting: #signedLonglong.
	self assert: interpreting get = ((SmallInteger minVal // 2) - 1).
	self assert: interpreting get = ((SmallInteger maxVal // 2) + 1)
!

testSignedShort
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #signedShort.
	interpreting put: -31000.
	interpreting put: 31000.
	interpreting := stream contents reading interpreting: #signedShort.
	self assert: interpreting get = -31000.
	self assert: interpreting get = 31000
!

testUnsignedChar
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #char.
	0 to: 255 do: [:each | interpreting put: each].
	self assert: (stream contents reading interpreting: #char) rest = (0 to: 255) asByteArray
!

testUnsignedLong
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #long.
	65000 to: 70000 do: [:each | interpreting put: each].
	self assert: ((stream contents reading interpreting: #long) rest isSameSequenceAs: (65000 to: 70000))
!

testUnsignedLongLong
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #longlong.
	(SmallInteger maxVal - 100) to: (SmallInteger maxVal + 100) do: [:each | interpreting put: each].
	self assert: ((stream contents reading interpreting: #longlong) rest isSameSequenceAs: ((SmallInteger maxVal - 100) to: (SmallInteger maxVal + 100)))
!

testUnsignedShort
	| interpreting |
	stream := ByteArray new writing.
	interpreting := stream interpreting: #short.
	250 to: 270 do: [:each | interpreting put: each].
	self assert: (stream contents reading interpreting: #short) rest asArray = (250 to: 270) asArray
! !

!InterpretingStreamTest class methodsFor:'documentation'!

version_HG

    ^ '$Changeset: <not expanded> $'
! !

